#!/bin/bash

# 
# Draft script to package VNX scenarios
#
# Author: David Fernández (david@dit.upm.es)
#
# This file is part of the Virtual Networks over LinuX (VNX) Project distribution. 
# (www: http://www.dit.upm.es/vnx - e-mail: vnx@dit.upm.es) 
# 
# Departamento de Ingenieria de Sistemas Telematicos (DIT)
# Universidad Politecnica de Madrid
# SPAIN
#

USAGE="vnx_pack_scenario: simple script to package VNX scenarios in a tgz file 

Usage:  vnx_pack_scenario -f <scenario_dir> [-v <version>]
"

#echo "num args=$#"
if [ "$#" -lt 2 ]; then
    echo -e "\nERROR: Invalid number of parameters" 
    echo -e "\n$USAGE\n"
    exit 1
fi

while getopts ":f:v:h" opt; do
    case "$opt" in
        f)
            SCENARIO="$OPTARG" 
            if [ ! -d $SCENARIO ]; then 
                echo -e "\nERROR: scenario $SCENARIO does not exist\n"
                exit 1
            fi
            ;;
        v)
            VER="$OPTARG" 
            ;;
        h)
            echo -e "\n$USAGE\n"
            exit 0 
            ;;
        \?)
            echo "\nERROR: Invalid option '-$OPTARG'\n"
            exit 1
            ;;
    esac
done




if [ $VER ]; then
    TGZNAME=${SCENARIO}-v${VER}
else
    TGZNAME=${SCENARIO}
fi

echo "Packaging scenario $SCENARIO"

tar cfvz ${TGZNAME}.tgz \
  $SCENARIO/*.xml  \
  $SCENARIO/*.cvnx \
  $SCENARIO/conf   \
  $SCENARIO/filesystems/create* \
  $SCENARIO/filesystems/rootfs*
